=== modified file 'lib/lp/code/errors.py'
--- lib/lp/code/errors.py	2011-08-24 13:09:29 +0000
+++ lib/lp/code/errors.py	2011-10-25 04:43:18 +0000
@@ -1,4 +1,4 @@
-# Copyright 2009 Canonical Ltd.  This software is licensed under the
+# Copyright 2009-2011 Canonical Ltd.  This software is licensed under the
 # GNU Affero General Public License version 3 (see the file LICENSE).
 
 """Errors used in the lp/code modules."""
@@ -15,6 +15,7 @@
     'BranchCreatorNotMemberOfOwnerTeam',
     'BranchCreatorNotOwner',
     'BranchExists',
+    'BranchHasPendingWrites',
     'BranchTargetError',
     'BranchTypeError',
     'BuildAlreadyPending',
@@ -39,6 +40,7 @@
     'TooManyBuilds',
     'TooNewRecipeFormat',
     'UnknownBranchTypeError',
+    'UpdatePreviewDiffNotReady',
     'UpgradePending',
     'UserHasExistingReview',
     'UserNotBranchReviewer',
@@ -92,6 +94,15 @@
         BranchCreationException.__init__(self, message)
 
 
+class BranchHasPendingWrites(Exception):
+    """Raised if the branch can't be processed because a write is pending.
+
+    In this case the operation can usually be retried in a while.
+
+    See bug 612171.
+    """
+
+
 class BranchTargetError(Exception):
     """Raised when there is an error determining a branch target."""
 
@@ -284,6 +295,10 @@
     """The requested review is not in a pending state."""
 
 
+class UpdatePreviewDiffNotReady(Exception):
+    """Raised if the the preview diff is not ready to run."""
+
+
 class UserHasExistingReview(Exception):
     """The user has an existing review."""
 

=== modified file 'lib/lp/code/model/branchmergeproposaljob.py'
--- lib/lp/code/model/branchmergeproposaljob.py	2011-10-25 04:34:00 +0000
+++ lib/lp/code/model/branchmergeproposaljob.py	2011-10-25 04:43:18 +0000
@@ -13,7 +13,6 @@
 
 
 __all__ = [
-    'BranchHasPendingWrites',
     'BranchMergeProposalJob',
     'BranchMergeProposalJobFactory',
     'BranchMergeProposalJobSource',
@@ -73,6 +72,10 @@
     )
 from lp.code.adapters.branch import BranchMergeProposalDelta
 from lp.code.enums import BranchType
+from lp.code.errors import (
+    BranchHasPendingWrites,
+    UpdatePreviewDiffNotReady,
+    )
 from lp.code.interfaces.branchmergeproposal import (
     IBranchMergeProposalJob,
     IBranchMergeProposalJobSource,
@@ -329,19 +332,6 @@
              self.branch_merge_proposal.target_branch.bzr_identity))
 
 
-class UpdatePreviewDiffNotReady(Exception):
-    """Raised if the the preview diff is not ready to run."""
-
-
-class BranchHasPendingWrites(Exception):
-    """Raised if the branch can't be processed because a write is pending.
-
-    In this case the operation can usually be retried in a while.
-
-    See bug 612171.
-    """
-
-
 class UpdatePreviewDiffJob(BranchMergeProposalJobDerived):
     """A job to update the preview diff for a branch merge proposal.
 

